@@ -5,13 +5,13 @@ import (
 	"encoding/json"
 	"fmt"
 	"io/ioutil"
-	"net"
 	"os"
 
 	igntypes "github.com/coreos/ignition/config/v2_2/types"
-	ospclientconfig "github.com/gophercloud/utils/openstack/clientconfig"
 	gcpprovider "github.com/openshift/cluster-api-provider-gcp/pkg/apis/gcpprovider/v1beta1"
 	libvirtprovider "github.com/openshift/cluster-api-provider-libvirt/pkg/apis/libvirtproviderconfig/v1beta1"
+	ovirtprovider "github.com/openshift/cluster-api-provider-ovirt/pkg/apis/ovirtprovider/v1beta1"
+	vsphereprovider "github.com/openshift/machine-api-operator/pkg/apis/vsphereprovider/v1alpha1"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 	awsprovider "sigs.k8s.io/cluster-api-provider-aws/pkg/apis/awsproviderconfig/v1beta1"
@@ -25,6 +25,8 @@ import (
 	"github.com/openshift/installer/pkg/asset/installconfig"
 	azureconfig "github.com/openshift/installer/pkg/asset/installconfig/azure"
 	gcpconfig "github.com/openshift/installer/pkg/asset/installconfig/gcp"
+	openstackconfig "github.com/openshift/installer/pkg/asset/installconfig/openstack"
+	ovirtconfig "github.com/openshift/installer/pkg/asset/installconfig/ovirt"
 	"github.com/openshift/installer/pkg/asset/machines"
 	"github.com/openshift/installer/pkg/asset/openshiftinstall"
 	"github.com/openshift/installer/pkg/asset/rhcos"
@@ -35,6 +37,8 @@ import (
 	gcptfvars "github.com/openshift/installer/pkg/tfvars/gcp"
 	libvirttfvars "github.com/openshift/installer/pkg/tfvars/libvirt"
 	openstacktfvars "github.com/openshift/installer/pkg/tfvars/openstack"
+	ovirttfvars "github.com/openshift/installer/pkg/tfvars/ovirt"
+	vspheretfvars "github.com/openshift/installer/pkg/tfvars/vsphere"
 	"github.com/openshift/installer/pkg/types"
 	"github.com/openshift/installer/pkg/types/aws"
 	"github.com/openshift/installer/pkg/types/azure"
@@ -44,6 +48,7 @@ import (
 	"github.com/openshift/installer/pkg/types/none"
 	"github.com/openshift/installer/pkg/types/openstack"
 	openstackdefaults "github.com/openshift/installer/pkg/types/openstack/defaults"
+	"github.com/openshift/installer/pkg/types/ovirt"
 	"github.com/openshift/installer/pkg/types/vsphere"
 )
 
@@ -102,7 +107,7 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 
 	platform := installConfig.Config.Platform.Name()
 	switch platform {
-	case none.Name, vsphere.Name:
+	case none.Name:
 		return errors.Errorf("cannot create the cluster because %q is a UPI platform", platform)
 	}
 
@@ -121,12 +126,22 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 		}
 	}
 
+	machineV4CIDRs, machineV6CIDRs := []string{}, []string{}
+	for _, network := range installConfig.Config.Networking.MachineNetwork {
+		if network.CIDR.IPNet.IP.To4() != nil {
+			machineV4CIDRs = append(machineV4CIDRs, network.CIDR.IPNet.String())
+		} else {
+			machineV6CIDRs = append(machineV6CIDRs, network.CIDR.IPNet.String())
+		}
+	}
+
 	masterCount := len(mastersAsset.MachineFiles)
 	data, err := tfvars.TFVars(
 		clusterID.InfraID,
 		installConfig.Config.ClusterDomain(),
 		installConfig.Config.BaseDomain,
-		&installConfig.Config.Networking.MachineNetwork[0].CIDR.IPNet,
+		machineV4CIDRs,
+		machineV6CIDRs,
 		useIPv4,
 		useIPv6,
 		bootstrapIgn,
@@ -230,18 +245,6 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 			workerConfigs[i] = w.Spec.Template.Spec.ProviderSpec.Value.Object.(*azureprovider.AzureMachineProviderSpec)
 		}
 
-		var (
-			machineV4CIDRs []net.IPNet
-			machineV6CIDRs []net.IPNet
-		)
-		for _, network := range installConfig.Config.Networking.MachineNetwork {
-			if network.CIDR.IPNet.IP.To4() != nil {
-				machineV4CIDRs = append(machineV4CIDRs, network.CIDR.IPNet)
-			} else {
-				machineV6CIDRs = append(machineV6CIDRs, network.CIDR.IPNet)
-			}
-		}
-
 		preexistingnetwork := installConfig.Config.Azure.VirtualNetwork != ""
 		data, err := azuretfvars.TFVars(
 			azuretfvars.TFVarsSources{
@@ -252,8 +255,6 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 				ImageURL:                    string(*rhcosImage),
 				PreexistingNetwork:          preexistingnetwork,
 				Publish:                     installConfig.Config.Publish,
-				MachineV4CIDRs:              machineV4CIDRs,
-				MachineV6CIDRs:              machineV6CIDRs,
 			},
 		)
 		if err != nil {
@@ -334,15 +335,13 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 			Data:     data,
 		})
 	case openstack.Name:
-		opts := &ospclientconfig.ClientOpts{}
-		opts.Cloud = installConfig.Config.Platform.OpenStack.Cloud
-		cloud, err := ospclientconfig.GetCloudFromYAML(opts)
+		cloud, err := openstackconfig.GetSession(installConfig.Config.Platform.OpenStack.Cloud)
 		if err != nil {
 			return errors.Wrap(err, "failed to get cloud config for openstack")
 		}
 		var caCert string
 		// Get the ca-cert-bundle key if there is a value for cacert in clouds.yaml
-		if caPath := cloud.CACertFile; caPath != "" {
+		if caPath := cloud.CloudConfig.CACertFile; caPath != "" {
 			caFile, err := ioutil.ReadFile(caPath)
 			if err != nil {
 				return errors.Wrap(err, "failed to read clouds.yaml ca-cert from disk")
@@ -406,6 +405,82 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 			Filename: fmt.Sprintf(TfPlatformVarsFileName, platform),
 			Data:     data,
 		})
+	case ovirt.Name:
+		config, err := ovirtconfig.NewConfig()
+		if err != nil {
+			return err
+		}
+		con, err := ovirtconfig.NewConnection()
+		if err != nil {
+			return err
+		}
+		defer con.Close()
+
+		if installConfig.Config.Platform.Ovirt.VNICProfileID == "" {
+			profiles, err := ovirtconfig.FetchVNICProfileByClusterNetwork(
+				con,
+				installConfig.Config.Platform.Ovirt.ClusterID,
+				installConfig.Config.Platform.Ovirt.NetworkName)
+			if err != nil {
+				return errors.Wrapf(err, "failed to compute values for oVirt platform")
+			}
+			if len(profiles) != 1 {
+				return errors.Wrapf(err, "failed to compute values for oVirt platform, there are multiple vNic profiles.")
+			}
+			installConfig.Config.Platform.Ovirt.VNICProfileID = profiles[0].MustId()
+		}
+
+		masters, err := mastersAsset.Machines()
+		if err != nil {
+			return err
+		}
+
+		data, err := ovirttfvars.TFVars(
+			ovirttfvars.Auth{
+				URL:      config.URL,
+				Username: config.Username,
+				Password: config.Password,
+				Cafile:   config.CAFile,
+			},
+			installConfig.Config.Platform.Ovirt.ClusterID,
+			installConfig.Config.Platform.Ovirt.StorageDomainID,
+			installConfig.Config.Platform.Ovirt.NetworkName,
+			installConfig.Config.Platform.Ovirt.VNICProfileID,
+			string(*rhcosImage),
+			clusterID.InfraID,
+			masters[0].Spec.ProviderSpec.Value.Object.(*ovirtprovider.OvirtMachineProviderSpec),
+		)
+		if err != nil {
+			return errors.Wrapf(err, "failed to get %s Terraform variables", platform)
+		}
+		t.FileList = append(t.FileList, &asset.File{
+			Filename: fmt.Sprintf(TfPlatformVarsFileName, platform),
+			Data:     data,
+		})
+	case vsphere.Name:
+		controlPlanes, err := mastersAsset.Machines()
+		if err != nil {
+			return err
+		}
+		controlPlaneConfigs := make([]*vsphereprovider.VSphereMachineProviderSpec, len(controlPlanes))
+		for i, c := range controlPlanes {
+			controlPlaneConfigs[i] = c.Spec.ProviderSpec.Value.Object.(*vsphereprovider.VSphereMachineProviderSpec)
+		}
+		data, err = vspheretfvars.TFVars(
+			vspheretfvars.TFVarsSources{
+				ControlPlaneConfigs: controlPlaneConfigs,
+				Username:            installConfig.Config.VSphere.Username,
+				Password:            installConfig.Config.VSphere.Password,
+				Cluster:             installConfig.Config.VSphere.Cluster,
+			},
+		)
+		if err != nil {
+			return errors.Wrapf(err, "failed to get %s Terraform variables", platform)
+		}
+		t.FileList = append(t.FileList, &asset.File{
+			Filename: fmt.Sprintf(TfPlatformVarsFileName, platform),
+			Data:     data,
+		})
 	default:
 		logrus.Warnf("unrecognized platform %s", platform)
 	}
